==> kvpnc_0.8.6.1.orig.tar.gz: kvpnc-0.8.6.1.orig/src/profileracoonoptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "profileracoonoptions.h"

ProfileRacoonOptions::ProfileRacoonOptions(QWidget *parent)
		: ProfileRacoonOptionsBase(parent)
{}


ProfileRacoonOptions::~ProfileRacoonOptions()
{}

==> kvpnc_0.8.9.orig.tar.gz: kvpnc-0.8.9.orig/src/profileracoonoptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "profileracoonoptions.h"

#include <klineedit.h>
#include <qcheckbox.h>

ProfileRacoonOptions::ProfileRacoonOptions(QWidget *parent)
		: ProfileRacoonOptionsBase(parent)
{}


ProfileRacoonOptions::~ProfileRacoonOptions()
{}
void ProfileRacoonOptions::useRightNextHopToggled(bool)
{
	if (UseRightNextHopCheckBox->isChecked())
		RightNextHopLineEdit->setEnabled(true);
	else
		RightNextHopLineEdit->setEnabled(false);
}


void ProfileRacoonOptions::useLeftNextHopToggled(bool)
{
	if (UseLeftNextHopCheckBox->isChecked())
		LeftNextHopLineEdit->setEnabled(true);
	else
		LeftNextHopLineEdit->setEnabled(false);
}
